==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/hybridconnectivity/kotlin/inputs/ListEndpointIngressGatewayCredentialsPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridconnectivity.kotlin.inputs

import com.pulumi.azurenative.hybridconnectivity.inputs.ListEndpointIngressGatewayCredentialsPlainArgs.builder
import com.pulumi.azurenative.hybridconnectivity.kotlin.enums.ServiceName
import com.pulumi.core.Either
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property endpointName The endpoint name.
 * @property expiresin The is how long the endpoint access token is valid (in seconds).
 * @property resourceUri The fully qualified Azure Resource manager identifier of the resource to be connected.
 * @property serviceName The name of the service.
 */
public data class ListEndpointIngressGatewayCredentialsPlainArgs(
    public val endpointName: String,
    public val expiresin: Int? = null,
    public val resourceUri: String,
    public val serviceName: Either<String, ServiceName>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.hybridconnectivity.inputs.ListEndpointIngressGatewayCredentialsPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.hybridconnectivity.inputs.ListEndpointIngressGatewayCredentialsPlainArgs =
        com.pulumi.azurenative.hybridconnectivity.inputs.ListEndpointIngressGatewayCredentialsPlainArgs.builder()
            .endpointName(endpointName.let({ args0 -> args0 }))
            .expiresin(expiresin?.let({ args0 -> args0 }))
            .resourceUri(resourceUri.let({ args0 -> args0 }))
            .serviceName(
                serviceName?.let({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [ListEndpointIngressGatewayCredentialsPlainArgs].
 */
@PulumiTagMarker
public class ListEndpointIngressGatewayCredentialsPlainArgsBuilder internal constructor() {
    private var endpointName: String? = null

    private var expiresin: Int? = null

    private var resourceUri: String? = null

    private var serviceName: Either<String, ServiceName>? = null

    /**
     * @param value The endpoint name.
     */
    @JvmName("acodkprpiknnwffw")
    public suspend fun endpointName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.endpointName = mapped
    }

    /**
     * @param value The is how long the endpoint access token is valid (in seconds).
     */
    @JvmName("jgbxraqfxnbdximv")
    public suspend fun expiresin(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.expiresin = mapped
    }

    /**
     * @param value The fully qualified Azure Resource manager identifier of the resource to be connected.
     */
    @JvmName("faajqaorgtgmcjkk")
    public suspend fun resourceUri(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceUri = mapped
    }

    /**
     * @param value The name of the service.
     */
    @JvmName("seimvdudqdodyyio")
    public suspend fun serviceName(`value`: Either<String, ServiceName>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.serviceName = mapped
    }

    /**
     * @param value The name of the service.
     */
    @JvmName("bxitywbauoanqnja")
    public fun serviceName(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ServiceName>(value)
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.serviceName = mapped
    }

    /**
     * @param value The name of the service.
     */
    @JvmName("slunwiikliyddruc")
    public fun serviceName(`value`: ServiceName) {
        val toBeMapped = Either.ofRight<String, ServiceName>(value)
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.serviceName = mapped
    }

    internal fun build(): ListEndpointIngressGatewayCredentialsPlainArgs =
        ListEndpointIngressGatewayCredentialsPlainArgs(
            endpointName = endpointName ?: throw PulumiNullFieldException("endpointName"),
            expiresin = expiresin,
            resourceUri = resourceUri ?: throw PulumiNullFieldException("resourceUri"),
            serviceName = serviceName,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/hybridconnectivity/kotlin/inputs/ListEndpointIngressGatewayCredentialsPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridconnectivity.kotlin.inputs

import com.pulumi.azurenative.hybridconnectivity.inputs.ListEndpointIngressGatewayCredentialsPlainArgs.builder
import com.pulumi.azurenative.hybridconnectivity.kotlin.enums.ServiceName
import com.pulumi.core.Either
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property endpointName The endpoint name.
 * @property expiresin The is how long the endpoint access token is valid (in seconds).
 * @property resourceUri The fully qualified Azure Resource manager identifier of the resource to be connected.
 * @property serviceName The name of the service.
 */
public data class ListEndpointIngressGatewayCredentialsPlainArgs(
    public val endpointName: String,
    public val expiresin: Int? = null,
    public val resourceUri: String,
    public val serviceName: Either<String, ServiceName>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.hybridconnectivity.inputs.ListEndpointIngressGatewayCredentialsPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.hybridconnectivity.inputs.ListEndpointIngressGatewayCredentialsPlainArgs =
        com.pulumi.azurenative.hybridconnectivity.inputs.ListEndpointIngressGatewayCredentialsPlainArgs.builder()
            .endpointName(endpointName.let({ args0 -> args0 }))
            .expiresin(expiresin?.let({ args0 -> args0 }))
            .resourceUri(resourceUri.let({ args0 -> args0 }))
            .serviceName(
                serviceName?.let({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [ListEndpointIngressGatewayCredentialsPlainArgs].
 */
@PulumiTagMarker
public class ListEndpointIngressGatewayCredentialsPlainArgsBuilder internal constructor() {
    private var endpointName: String? = null

    private var expiresin: Int? = null

    private var resourceUri: String? = null

    private var serviceName: Either<String, ServiceName>? = null

    /**
     * @param value The endpoint name.
     */
    @JvmName("eowiyewsroqhkird")
    public suspend fun endpointName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.endpointName = mapped
    }

    /**
     * @param value The is how long the endpoint access token is valid (in seconds).
     */
    @JvmName("amakomicbaicusum")
    public suspend fun expiresin(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.expiresin = mapped
    }

    /**
     * @param value The fully qualified Azure Resource manager identifier of the resource to be connected.
     */
    @JvmName("lramrnyansifxfdw")
    public suspend fun resourceUri(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceUri = mapped
    }

    /**
     * @param value The name of the service.
     */
    @JvmName("eiyjmlfuacliwrph")
    public suspend fun serviceName(`value`: Either<String, ServiceName>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.serviceName = mapped
    }

    /**
     * @param value The name of the service.
     */
    @JvmName("kqakjjjkewwgmgtm")
    public fun serviceName(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ServiceName>(value)
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.serviceName = mapped
    }

    /**
     * @param value The name of the service.
     */
    @JvmName("prvnlkschecdcfos")
    public fun serviceName(`value`: ServiceName) {
        val toBeMapped = Either.ofRight<String, ServiceName>(value)
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.serviceName = mapped
    }

    internal fun build(): ListEndpointIngressGatewayCredentialsPlainArgs =
        ListEndpointIngressGatewayCredentialsPlainArgs(
            endpointName = endpointName ?: throw PulumiNullFieldException("endpointName"),
            expiresin = expiresin,
            resourceUri = resourceUri ?: throw PulumiNullFieldException("resourceUri"),
            serviceName = serviceName,
        )
}
